@@ -1,4 +1,5 @@
 use std::time::{Duration, Instant};
+use xecs::resource::Resource;
 
 pub struct States {
     pub(in super) quit : bool,
@@ -8,6 +9,8 @@ pub struct States {
     pub(in super) last_frame_time : Duration
 }
 
+impl Resource for States {}
+
 impl States {
     pub(in super) fn new() -> Self {
         States {
