@@ -2,13 +2,15 @@ use std::{pin::Pin, sync::Arc, task::{Context, Poll, Waker}};
 use crossbeam::channel::{Receiver, Sender, unbounded};
 use futures::Stream;
 use parking_lot::RwLock;
-use xecs::{entity::EntityId, system::System, world::World};
+use xecs::{component::Component, entity::EntityId, system::System, world::World};
 
 pub(in crate) struct EnterFrameInner {
     pub(in crate) tx : Sender<u32>,
     pub(in crate) waker : Waker
 }
 
+impl Component for EnterFrameInner {}
+
 pub struct EnterFrame {
     world : Arc<RwLock<World>>,
     rx : Option<(EntityId,Receiver<u32>)>
