@@ -3,7 +3,7 @@ use crossbeam::channel::{Receiver, Sender, unbounded};
 use futures::Stream;
 use parking_lot::RwLock;
 use sdl2_sys::SDL_TextInputEvent;
-use xecs::{entity::EntityId, query::WithId, system::System, world::World};
+use xecs::{component::Component, entity::EntityId, query::WithId, system::System, world::World};
 use crate::{common::from_sdl_string, window::Window};
 
 #[derive(Debug,Clone)]
@@ -37,6 +37,8 @@ pub(in crate) struct TextInputInner{
     pub(in crate) waker : Waker
 }
 
+impl Component for TextInputInner {}
+
 pub struct TextInput{
     world : Arc<RwLock<World>>,
     rx : Option<(EntityId,Receiver<EventInfo>)>
