@@ -3,7 +3,7 @@ use crossbeam::channel::{Receiver, Sender, unbounded};
 use futures::Stream;
 use parking_lot::RwLock;
 use sdl2_sys::SDL_MouseButtonEvent;
-use xecs::{entity::EntityId, query::WithId, system::System, world::World};
+use xecs::{component::Component, entity::EntityId, query::WithId, system::System, world::World};
 use crate::window::Window;
 
 #[derive(Debug, Copy, Clone, PartialOrd, PartialEq)]
@@ -71,6 +71,8 @@ pub(in crate) struct ButtonDownInner {
     pub(in crate) waker : Waker
 }
 
+impl Component for ButtonDownInner {}
+
 pub struct ButtonDown {
     world : Arc<RwLock<World>>,
     rx : Option<(EntityId,Receiver<EventInfo>)>
@@ -134,6 +136,8 @@ pub(in crate) struct ButtonUpInner {
     pub(in crate) waker : Waker
 }
 
+impl Component for ButtonUpInner {}
+
 pub struct ButtonUp {
     world : Arc<RwLock<World>>,
     rx : Option<(EntityId,Receiver<EventInfo>)>
