@@ -1,3 +1,4 @@
+use xecs::resource::Resource;
 use crate::sysinfo::cpu_info::CPUInfo;
 use crate::sysinfo::platform_info::PlatformInfo;
 use crate::sysinfo::video_info::VideoInfo;
@@ -13,6 +14,8 @@ pub struct SystemInfo {
     video: VideoInfo,
 }
 
+impl Resource for SystemInfo {}
+
 impl SystemInfo {
     pub(in crate) fn new() -> SystemInfo {
         SystemInfo {
